Outcome. The name of a numeric variable (can be binary and take values of 0 and 1).
D
Treatment status. The name of a binary numeric variable taking values of 0 and 1.
G
Advantaged group membership. The name of a binary numeric variable taking values of 0 and 1.
X
Confounders. A vector of variable names.
data
A data frame.
alpha
1-alpha confidence interval.
trim
Threshold for trimming the propensity score. When trim=a, individuals with propensity scores lower than a or higher than 1-a will be dropped.
weight
Sampling weights. The name of a numeric variable. If unspecified, equal weights are used. Technically, the weight should be a deterministic function of X and G.